/**
 * @brief   Pin definitions and configuration
 * @file    pindef.h
 * @author  Ondrej Jerabek
 */

#ifndef PINDEF_H
#define PINDEF_H

#include <type.h>
#include <delay.h>

// LEDs
#define LED_SYS_DIR(val)			Chip_GPIO_WriteDirBit(LPC_GPIO, 1, 30, val)
#define LED_SYS(val)				Chip_GPIO_WritePortBit(LPC_GPIO, 1, 30, val)
#define LED_STAT_DIR(val)			Chip_GPIO_WriteDirBit(LPC_GPIO, 3, 23, val)
#define LED_STAT(val)				Chip_GPIO_WritePortBit(LPC_GPIO, 3, 23, val)
#define LEDG_DIR(val)				Chip_GPIO_WriteDirBit(LPC_GPIO, 1, 21, val)
#define LEDG(val)					Chip_GPIO_WritePortBit(LPC_GPIO, 1, 21, val)
#define LEDR_DIR(val)				Chip_GPIO_WriteDirBit(LPC_GPIO, 1, 20, val)
#define LEDR(val)					Chip_GPIO_WritePortBit(LPC_GPIO, 1, 20, val)
#define LEDY2_DIR(val)				Chip_GPIO_WriteDirBit(LPC_GPIO, 1, 18, val)
#define LEDY2(val)					Chip_GPIO_WritePortBit(LPC_GPIO, 1, 18, val)
#define LEDY1_DIR(val)				Chip_GPIO_WriteDirBit(LPC_GPIO, 1, 19, val)
#define LEDY1(val)					Chip_GPIO_WritePortBit(LPC_GPIO, 1, 19, val)

// Buzzer
#define BUZZ_DIR(val)				Chip_GPIO_WriteDirBit(LPC_GPIO, 0, 3, val)
#define BUZZ(val)					Chip_GPIO_WritePortBit(LPC_GPIO, 0, 3, val)

// Charger
#define CHRG_EN1_DIR(val)			Chip_GPIO_WriteDirBit(LPC_GPIO, 5, 4, val)
#define CHRG_EN1(val)				Chip_GPIO_WritePortBit(LPC_GPIO, 5, 4, val)
#define CHRG_EN2_DIR(val)			Chip_GPIO_WriteDirBit(LPC_GPIO, 5, 0, val)
#define CHRG_EN2(val)				Chip_GPIO_WritePortBit(LPC_GPIO, 5, 0, val)
#define CHRG_CE_DIR(val)			Chip_GPIO_WriteDirBit(LPC_GPIO, 1, 31, val)
#define CHRG_CE(val)				Chip_GPIO_WritePortBit(LPC_GPIO, 1, 31, val)
#define CHRG_PWR_GOOD				Chip_GPIO_GetPinState(LPC_GPIO, 4, 29)
#define CHRG_CHARGING				Chip_GPIO_GetPinState(LPC_GPIO, 5, 1)

// Button / Power
#define BUTTON_DIR(val)				Chip_GPIO_WriteDirBit(LPC_GPIO, 0, 2, val)
#define BUTTON						Chip_GPIO_GetPinState(LPC_GPIO, 0, 2)
#define POWER_DIR(val)				Chip_GPIO_WriteDirBit(LPC_GPIO, 0, 28, val)
#define POWER(val)					Chip_GPIO_WritePortBit(LPC_GPIO, 0, 28, !val)

// Dallas
#define DS_DIR(val)					Chip_GPIO_WriteDirBit(LPC_GPIO, 1, 22, val)
#define DS_OUT(val)					Chip_GPIO_WritePortBit(LPC_GPIO, 1, 22, val)
#define DS_IN						Chip_GPIO_GetPinState(LPC_GPIO, 1, 22)

// Memory
#define SPI_EEPROM_CS_DIR(val)		Chip_GPIO_WriteDirBit(LPC_GPIO, 0, 16, val)
#define SPI_EEPROM_CS				Chip_GPIO_WriteDirBit(LPC_GPIO, 0, 16, 0)
#define spi_eeprom_select()			Chip_GPIO_WritePortBit(LPC_GPIO, 0, 16, 0)
#define spi_eeprom_unselect()		Chip_GPIO_WritePortBit(LPC_GPIO, 0, 16, 1)
#define EXTFLASH_CS_DIR(val)		Chip_GPIO_WriteDirBit(LPC_GPIO, 5, 2, val)
#define EXTFLASH_CS_IN				Chip_GPIO_WriteDirBit(LPC_GPIO, 5, 2, 0)
#define EXTFLASH_CS(val)			Chip_GPIO_WritePortBit(LPC_GPIO, 5, 2, val)
#define EXTFLASH_SELECT(addr)		EXTFLASH_CS(0), delayus_fcn(10)
#define EXTFLASH_UNSELECT()			EXTFLASH_CS(1), delayus_fcn(10)
#define SD_DETECT_DIR(val)			Chip_GPIO_WriteDirBit(LPC_GPIO, 0, 1, val)
#define SD_DETECT					Chip_GPIO_GetPinState(LPC_GPIO, 0, 1)

// USB
#define USB_CON_DIR(val)			Chip_GPIO_WriteDirBit(LPC_GPIO, 0, 14, val)
#define USB_CON(val)				Chip_GPIO_WritePortBit(LPC_GPIO, 0, 14, val)

// Modules connection
#define MODULE1_RESET_DIR(val)		Chip_GPIO_WriteDirBit(LPC_GPIO, 2, 9, val)
#define MODULE1_RESET(val)			Chip_GPIO_WritePortBit(LPC_GPIO, 2, 9, val)
#define MODULE2_RESET_DIR(val)		Chip_GPIO_WriteDirBit(LPC_GPIO, 2, 3, val)
#define MODULE2_RESET(val)			Chip_GPIO_WritePortBit(LPC_GPIO, 2, 3, val)
#define MODULE1_PWR_DIR(val)		Chip_GPIO_WriteDirBit(LPC_GPIO, 5, 3, val)
#define MODULE1_PWR(val)			Chip_GPIO_WritePortBit(LPC_GPIO, 5, 3, val)
#define MODULE2_PWR_DIR(val)		Chip_GPIO_WriteDirBit(LPC_GPIO, 4, 28, val)
#define MODULE2_PWR(val)			Chip_GPIO_WritePortBit(LPC_GPIO, 4, 28, val)

// SX1211_1
#define IRQ_01_DIR(val)				Chip_GPIO_WriteDirBit(LPC_GPIO, 2, 4, val)
#define IRQ_11_DIR(val)				Chip_GPIO_WriteDirBit(LPC_GPIO, 2, 5, val)
#define IRQ01_PIN					4
#define IRQ11_PIN					5
#define IRQ_01						Chip_GPIO_GetPinState(LPC_GPIO, 2, 4)
#define IRQ_11						Chip_GPIO_GetPinState(LPC_GPIO, 2, 5)
#define SX_CONFIG_SELECT1_DIR(val)	Chip_GPIO_WriteDirBit(LPC_GPIO, 2, 7, val)
#define SX_CONFIG_SELECT1()			Chip_GPIO_WritePortBit(LPC_GPIO, 2, 7, 0), Chip_GPIO_WritePortBit(LPC_GPIO, 0, 6, 0)
#define SX_CONFIG_UNSELECT1()		Chip_GPIO_WritePortBit(LPC_GPIO, 2, 7, 1), Chip_GPIO_WritePortBit(LPC_GPIO, 0, 6, 1)
#define SX_DATA_SELECT1_DIR(val)	Chip_GPIO_WriteDirBit(LPC_GPIO, 0, 6, val)
#define SX_DATA_SELECT1()			Chip_GPIO_WritePortBit(LPC_GPIO, 0, 6, 0)
#define SX_DATA_UNSELECT1()			Chip_GPIO_WritePortBit(LPC_GPIO, 0, 6, 1)
#define NSS_CONFIG1					Chip_GPIO_ReadPortBit(LPC_GPIO, 2, 7)
#define NSS_DATA1					Chip_GPIO_ReadPortBit(LPC_GPIO, 0, 6)
#define SX_PLLLOCK1_DIR(val)		Chip_GPIO_WriteDirBit(LPC_GPIO, 3, 25, val)
#define SX_PLLLOCK1				Chip_GPIO_GetPinState(LPC_GPIO, 3, 25)
#define SX_RESET1_DIR				MODULE0_RESET_DIR
#define SX_RESET1(val)				MODULE0_RESET(val)
#define SX_EE_CS1_DIR(val)			Chip_GPIO_WriteDirBit(LPC_GPIO, 2, 6, val)
#define SX_EE_CS1(val)				Chip_GPIO_WritePortBit(LPC_GPIO, 2, 6, val)
#define SX_EE_CS1_PIN				Chip_GPIO_ReadPortBit(LPC_GPIO, 2, 6)

// SX1211_2
#define IRQ_02_DIR(val)				Chip_GPIO_WriteDirBit(LPC_GPIO, 2, 0, val)
#define IRQ_12_DIR(val)				Chip_GPIO_WriteDirBit(LPC_GPIO, 2, 1, val)
#define IRQ02_PIN					0
#define IRQ12_PIN					1
#define IRQ_02						Chip_GPIO_GetPinState(LPC_GPIO, 2, 0)
#define IRQ_12						Chip_GPIO_GetPinState(LPC_GPIO, 2, 1)
#define SX_CONFIG_SELECT2_DIR(val)	Chip_GPIO_WriteDirBit(LPC_GPIO, 0, 4, val)
#define SX_CONFIG_SELECT2()			Chip_GPIO_WritePortBit(LPC_GPIO, 0, 4, 0), Chip_GPIO_WritePortBit(LPC_GPIO, 0, 5, 0)
#define SX_CONFIG_UNSELECT2()		Chip_GPIO_WritePortBit(LPC_GPIO, 0, 4, 1), Chip_GPIO_WritePortBit(LPC_GPIO, 0, 5, 1)
#define SX_DATA_SELECT2_DIR(val)	Chip_GPIO_WriteDirBit(LPC_GPIO, 0, 5, val)
#define SX_DATA_SELECT2()			Chip_GPIO_WritePortBit(LPC_GPIO, 0, 5, 0)
#define SX_DATA_UNSELECT2()			Chip_GPIO_WritePortBit(LPC_GPIO, 0, 5, 1)
#define NSS_CONFIG2					Chip_GPIO_ReadPortBit(LPC_GPIO, 0, 4)
#define NSS_DATA2					Chip_GPIO_ReadPortBit(LPC_GPIO, 0, 5)
#define SX_PLLLOCK2_DIR(val)		Chip_GPIO_WriteDirBit(LPC_GPIO, 3, 26, val)
#define SX_PLLLOCK2					Chip_GPIO_GetPinState(LPC_GPIO, 3, 26)
#define SX_RESET2_DIR				MODULE1_RESET_DIR
#define SX_RESET2(val)				MODULE1_RESET(val)
#define SX_EE_CS2_DIR(val)			Chip_GPIO_WriteDirBit(LPC_GPIO, 2, 2, val)
#define SX_EE_CS2(val)				Chip_GPIO_WritePortBit(LPC_GPIO, 2, 2, val)
#define SX_EE_CS2_PIN				Chip_GPIO_ReadPortBit(LPC_GPIO, 2, 2)

// DECAWAVE_0
#define IRQ_DW0_DIR(val)			Chip_GPIO_WriteDirBit(LPC_GPIO, 2, 4, val)
#define IRQ_DW0						Chip_GPIO_GetPinState(LPC_GPIO, 2, 4)
#define DW_D3_0_DIR(val)			Chip_GPIO_WriteDirBit(LPC_GPIO, 2, 5, val)
#define DW_D3_0(val)				Chip_GPIO_WritePortBit(LPC_GPIO, 2, 5, val)
#define DW_HGM_0_DIR(val)			Chip_GPIO_WriteDirBit(LPC_GPIO, 2, 7, val)
#define DW_HGM_0(val)				Chip_GPIO_WritePortBit(LPC_GPIO, 2, 7, val)
#define DW_EN_0_DIR(val)			Chip_GPIO_WriteDirBit(LPC_GPIO, 2, 6, val)
#define DW_EN_0(val)				Chip_GPIO_WritePortBit(LPC_GPIO, 2, 6, val)
#define DW_CS_0_DIR(val)			Chip_GPIO_WriteDirBit(LPC_GPIO, 0, 6, val)
#define DW_CS_0(val)				Chip_GPIO_WritePortBit(LPC_GPIO, 0, 6, val)

// DECAWAVE_1
#define IRQ_DW1_DIR(val)			Chip_GPIO_WriteDirBit(LPC_GPIO, 2, 0, val)
#define IRQ_DW1						Chip_GPIO_GetPinState(LPC_GPIO, 2, 0)
#define DW_D3_1_DIR(val)			Chip_GPIO_WriteDirBit(LPC_GPIO, 2, 1, val)
#define DW_D3_1(val)				Chip_GPIO_WritePortBit(LPC_GPIO, 2, 1, val)
#define DW_HGM_1_DIR(val)			Chip_GPIO_WriteDirBit(LPC_GPIO, 0, 4, val)
#define DW_HGM_1(val)				Chip_GPIO_WritePortBit(LPC_GPIO, 0, 4, val)
#define DW_EN_1_DIR(val)			Chip_GPIO_WriteDirBit(LPC_GPIO, 2, 2, val)
#define DW_EN_1(val)				Chip_GPIO_WritePortBit(LPC_GPIO, 2, 2, val)
#define DW_CS_1_DIR(val)			Chip_GPIO_WriteDirBit(LPC_GPIO, 0, 5, val)
#define DW_CS_1(val)				Chip_GPIO_WritePortBit(LPC_GPIO, 0, 5, val)

#define DW_WSYNC_DIR(val)			Chip_GPIO_WriteDirBit(LPC_GPIO, 2, 8, val)
#define DW_WSYNC(val)				Chip_GPIO_WritePortBit(LPC_GPIO, 2, 8, val)

// nanoLOC cip 1
#define NTRX_1_N_RESET_DIR(val)	MODULE1_RESET_DIR(val)
#define NTRX_1_N_RESET(val)		MODULE1_RESET(val)
#define NTRX_1_CS_DIR(val)		Chip_GPIO_WriteDirBit(LPC_GPIO, 0, 6, val)
#define NTRX_1_CS(val)			Chip_GPIO_WritePortBit(LPC_GPIO, 0, 6, val)
#define NTRX_1_PAEN_DIR(val)	Chip_GPIO_WriteDirBit(LPC_GPIO, 2, 6, val)
#define NTRX_1_PAEN(val)		Chip_GPIO_WritePortBit(LPC_GPIO, 2, 6, val)
#define NTRX_1_EN_DIR(val)		Chip_GPIO_WriteDirBit(LPC_GPIO, 2, 6, val)
#define NTRX_1_EN(val)			Chip_GPIO_WritePortBit(LPC_GPIO, 2, 6, val)
#define NTRX_1_HGM_DIR(val)		Chip_GPIO_WriteDirBit(LPC_GPIO, 2, 7, val)
#define NTRX_1_HGM(val)			Chip_GPIO_WritePortBit(LPC_GPIO, 2, 7, val)

#define NTRX_1_IRQ_DIR(val)		Chip_GPIO_WriteDirBit(LPC_GPIO, 2, 4, val)
#define NTRX_1_IRQ				Chip_GPIO_GetPinState(LPC_GPIO, 2, 4)
#define NTRX_1_VCC_DIR(val)		Chip_GPIO_WriteDirBit(LPC_GPIO, 3, 25, val)
#define NTRX_1_VCC				Chip_GPIO_GetPinState(LPC_GPIO, 3, 25)
#define NTRX_1_M_RESET			// not connected
#define NTRX_1_D3_DIR(val)		Chip_GPIO_WriteDirBit(LPC_GPIO, 2, 5, val)
#define NTRX_1_D3				Chip_GPIO_GetPinState(LPC_GPIO, 2, 5)

// nanoLOC cip 2
#define NTRX_2_N_RESET_DIR(val)	MODULE2_RESET_DIR(val)
#define NTRX_2_N_RESET(val)		MODULE2_RESET(val)
#define NTRX_2_CS_DIR(val)		Chip_GPIO_WriteDirBit(LPC_GPIO, 0, 5, val)
#define NTRX_2_CS(val)			Chip_GPIO_WritePortBit(LPC_GPIO, 0, 5, val)
#define NTRX_2_PAEN_DIR(val)	Chip_GPIO_WriteDirBit(LPC_GPIO, 2, 2, val)
#define NTRX_2_PAEN(val)		Chip_GPIO_WritePortBit(LPC_GPIO, 2, 2, val)
#define NTRX_2_EN_DIR(val)		Chip_GPIO_WriteDirBit(LPC_GPIO, 2, 2, val)
#define NTRX_2_EN(val)			Chip_GPIO_WritePortBit(LPC_GPIO, 2, 2, val)
#define NTRX_2_HGM_DIR(val)		Chip_GPIO_WriteDirBit(LPC_GPIO, 0, 4, val)
#define NTRX_2_HGM(val)			Chip_GPIO_WritePortBit(LPC_GPIO, 0, 4, val)

#define NTRX_2_IRQ_DIR(val)		Chip_GPIO_WriteDirBit(LPC_GPIO, 2, 0, val)
#define NTRX_2_IRQ				Chip_GPIO_GetPinState(LPC_GPIO, 2, 0)
#define NTRX_2_VCC_DIR(val)		Chip_GPIO_WriteDirBit(LPC_GPIO, 3, 26, val)
#define NTRX_2_VCC				Chip_GPIO_GetPinState(LPC_GPIO, 3, 26)
#define NTRX_2_M_RESET			// not connected
#define NTRX_2_D3_DIR(val)		Chip_GPIO_WriteDirBit(LPC_GPIO, 2, 1, val)
#define NTRX_2_D3				Chip_GPIO_GetPinState(LPC_GPIO, 2, 1)

// --------------------------------------------------------------------------
/**
 * @brief 	Initialization of I/O pins and set to default values
 */
#define INIT_IO() {					\
			POWER_DIR(1);			\
			POWER(1);				\
			LED_STAT_DIR(1);		\
			LED_STAT(0);			\
			LED_SYS_DIR(1);			\
			LED_SYS(0);				\
			LEDR_DIR(1);			\
			LEDR(0);				\
			LEDG_DIR(1);			\
			LEDG(0);				\
			LEDY1_DIR(1);			\
			LEDY1(0);				\
			LEDY2_DIR(1);			\
			LEDY2(0);				\
			BUZZ_DIR(1);			\
			BUZZ(0);				\
			CHRG_EN1_DIR(1);		\
			CHRG_EN1(0);			\
			CHRG_EN2_DIR(1);		\
			CHRG_EN2(0);			\
			CHRG_CE_DIR(1);			\
			CHRG_CE(1);				\
			SPI_EEPROM_CS_DIR(1);	\
			spi_eeprom_unselect();	\
			EXTFLASH_CS_DIR(1);		\
			EXTFLASH_UNSELECT();	\
			SX_CONFIG_SELECT1_DIR(1);\
			SX_CONFIG_UNSELECT1();	\
			SX_DATA_SELECT1_DIR(1);	\
			SX_DATA_UNSELECT1();	\
			SX_CONFIG_SELECT2_DIR(1);\
			SX_CONFIG_UNSELECT2();	\
			SX_DATA_SELECT2_DIR(1);	\
			SX_DATA_UNSELECT2();	\
			MODULE1_RESET_DIR(1);	\
			MODULE1_RESET(0);		\
			MODULE2_RESET_DIR(1);	\
			MODULE2_RESET(0);		\
			MODULE1_PWR_DIR(1);		\
			MODULE1_PWR(1);			\
			MODULE2_PWR_DIR(1);		\
			MODULE2_PWR(1);			\
			USB_CON_DIR(1);			\
			USB_CON(1);				\
			SX_EE_CS1_DIR(1);		\
			SX_EE_CS1(1);			\
			SX_EE_CS2_DIR(1);		\
			SX_EE_CS2(1);			\
}

/**
 * @brief 	Initialize default pin state and mode
 * @return	Nothing
 */
extern void pindef_init(void);

#endif
