/**
 * @brief   Power and charging control
 * @file    power_ctrl.h
 * @author  Ondrej Jerabek
 */

#ifndef POWER_CTRL_H_
#define POWER_CTRL_H_

/**
 * @brief Charger configuration
 */
enum e_chrg_mode
{
	CHRG_OFF,			/**< Charging off									*/
	CHRG_100MA,			/**< Charging on, maximum input current 100mA		*/
	CHRG_500MA,			/**< Charging on, maximum input current 500mA		*/
	CHRG_600MA,			/**< Charging on, maximum input current 600mA		*/
	CHRG_BATT_ONLY,		/**< Charging off, Device powered from battery only	*/
};

/**
 * @brief   Set charger power mode
 * @param	mode:	Current mode. Valid values avaible in enum e_chrg_mode
 * @return  Nothing
 */
extern void set_chrg_mode(enum e_chrg_mode mode);

/**
 * @brief  	Handling ADC measurement
 * @return  Nothing
 */
extern void pwr_meas_vals(void);

/**
 * @brief  	Device power off
 * @return  Nothing
 * @note	If device powered from external power, does nothing
 */
extern void pwr_suicide(void);

/**
 * @brief  	Handling power control and state indication
 * @return  Nothing
 */
extern void pwr_handle(void);

#endif /* POWER_CTRL_H_ */
