/**
 * @brief   Routing function
 * @file    routing.h
 * @author  Ondrej Jerabek
 * @note	Not fully implemented yet
 */

#ifndef _ROUTING_H_
#define _ROUTING_H_

#include "config.h"
#include <packet_handle.h>
#include <type.h>

/**
 * @brief Routing table item structure
 */
typedef struct {
	unsigned int addr;						/**< Device address */
	enum e_packet_source_device interface;	/**< Interface where is the device present */
	unsigned char timer;					/**< Timer for time out this item */
} ROUTING_TABLE_ITEM;

#ifndef ROUTING_TABLE_SIZE
#define ROUTING_TABLE_SIZE			32
#endif

#ifndef ROUTING_TABLE_TIMEOUT
#define ROUTING_TABLE_TIMEOUT		60		// [s]
#endif

// --------------------------------------------------------------------------
extern ROUTING_TABLE_ITEM routing_table[ROUTING_TABLE_SIZE];

// --------------------------------------------------------------------------
/**
 * @brief   Updating item in routing table
 * @param	addr:		Sorce device address
 * @param	interface:	Interface where is the device present
 * @return  Status of item update. True if item successfully updated/added
 */
extern bool routing_table_update(unsigned int addr, enum e_packet_source_device interface);

/**
 * @brief   Handle timers of the items in table
 * @return  Nothing
 * @note	Should be called each second
 */
extern void routing_table_timeout(void);

/**
 * @brief   Finding item in routing table
 * @param	addr:	Device address to find
 * @return  Source interface
 */
extern enum e_packet_source_device routing_table_find(unsigned int addr);

/**
 * @brief   Delete item from routing table
 * @param	addr:	Device address to delete
 * @return  Nothing
 */
extern void routing_table_device_del(unsigned int addr);

#endif // _ROUTING_H_
